@@ -20,7 +20,6 @@ IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
 
-
 const Lang = imports.lang;
 const Signals = imports.signals;
 const Mainloop = imports.mainloop;
@@ -35,7 +34,8 @@ const Layout = imports.ui.layout;
 const Main = imports.ui.main;
 
 const Gettext = imports.gettext.domain(
-    'EasyScreenCast@iacopodeenosee.gmail.com');
+    "EasyScreenCast@iacopodeenosee.gmail.com"
+);
 const _ = Gettext.gettext;
 
 const ExtensionUtils = imports.misc.extensionUtils;
@@ -56,26 +56,26 @@ const Capture = new Lang.Class({
      * @private
      */
     _init: function () {
-        Lib.TalkativeLog('-£-capture selection init');
+        Lib.TalkativeLog("-£-capture selection init");
 
         this._mouseDown = false;
 
         this.monitor = Main.layoutManager.focusMonitor;
 
         this._areaSelection = new St.Widget({
-            name: 'area-selection',
-            style_class: 'area-selection',
-            visible: 'true',
-            reactive: 'true',
+            name: "area-selection",
+            style_class: "area-selection",
+            visible: "true",
+            reactive: "true",
             x: -10,
-            y: -10
+            y: -10,
         });
 
         Main.uiGroup.add_actor(this._areaSelection);
 
         this._areaResolution = new St.Label({
-            style_class: 'area-resolution',
-            text: ""
+            style_class: "area-resolution",
+            text: "",
         });
         this._areaResolution.opacity = 255;
         this._areaResolution.set_position(0, 0);
@@ -84,22 +84,23 @@ const Capture = new Lang.Class({
 
         if (Main.pushModal(this._areaSelection)) {
             this._signalCapturedEvent = global.stage.connect(
-                'captured-event', this._onCaptureEvent.bind(this)
+                "captured-event",
+                this._onCaptureEvent.bind(this)
             );
 
             this._setCaptureCursor();
         } else {
-            Lib.TalkativeLog('-£-Main.pushModal() === false');
+            Lib.TalkativeLog("-£-Main.pushModal() === false");
         }
 
-        Main.sessionMode.connect('updated', () => this._updateDraw());
+        Main.sessionMode.connect("updated", () => this._updateDraw());
     },
 
     /**
      * @private
      */
     _updateDraw: function () {
-        Lib.TalkativeLog('-£-update draw capture');
+        Lib.TalkativeLog("-£-update draw capture");
     },
 
     /**
@@ -138,12 +139,7 @@ const Capture = new Lang.Class({
      * @param {Number} h
      * @param {boolean} showResolution
      */
-    drawSelection: function ({
-                                 x,
-                                 y,
-                                 w,
-                                 h
-                             }, showResolution) {
+    drawSelection: function ({ x, y, w, h }, showResolution) {
         this._areaSelection.set_position(x, y);
         this._areaSelection.set_size(w, h);
 
@@ -151,7 +147,8 @@ const Capture = new Lang.Class({
             this._areaResolution.set_text(w + " X " + h);
             this._areaResolution.set_position(
                 x + (w / 2 - this._areaResolution.width / 2),
-                y + (h / 2 - this._areaResolution.height / 2));
+                y + (h / 2 - this._areaResolution.height / 2)
+            );
         } else {
             this._areaResolution.set_position(0, 0);
             this._areaResolution.set_text("");
@@ -162,19 +159,22 @@ const Capture = new Lang.Class({
      * Clear drawing selection
      */
     clearSelection: function () {
-        this.drawSelection({
-            x: -10,
-            y: -10,
-            w: 0,
-            h: 0
-        }, false);
+        this.drawSelection(
+            {
+                x: -10,
+                y: -10,
+                w: 0,
+                h: 0,
+            },
+            false
+        );
     },
 
     /**
      * @private
      */
     _stop: function () {
-        Lib.TalkativeLog('-£-capture selection stop');
+        Lib.TalkativeLog("-£-capture selection stop");
 
         global.stage.disconnect(this._signalCapturedEvent);
         this._setDefaultCursor();
@@ -187,8 +187,9 @@ const Capture = new Lang.Class({
     },
 
     _saveRect: function (x, y, h, w) {
-        Lib.TalkativeLog('-£-selection x:' + x + ' y:' + y +
-            ' height:' + h + ' width:' + w);
+        Lib.TalkativeLog(
+            "-£-selection x:" + x + " y:" + y + " height:" + h + " width:" + w
+        );
 
         Settings.setOption(Settings.X_POS_SETTING_KEY, x);
         Settings.setOption(Settings.Y_POS_SETTING_KEY, y);
@@ -196,28 +197,29 @@ const Capture = new Lang.Class({
         Settings.setOption(Settings.WIDTH_SETTING_KEY, w);
 
         Ext.Indicator._doDelayAction();
-    }
+    },
 });
 
 Signals.addSignalMethods(Capture.prototype);
 
-const SelectionArea = new Lang.Class({
+var SelectionArea = new Lang.Class({
     Name: "EasyScreenCast.SelectionArea",
 
     /**
      * @private
      */
     _init: function () {
-        Lib.TalkativeLog('-£-area selection init');
+        Lib.TalkativeLog("-£-area selection init");
 
         this._mouseDown = false;
         this._capture = new Capture();
-        this._capture.connect('captured-event', this._onEvent.bind(this));
-        this._capture.connect('stop', this.emit.bind(this, 'stop'));
+        this._capture.connect("captured-event", this._onEvent.bind(this));
+        this._capture.connect("stop", this.emit.bind(this, "stop"));
 
         let CtrlNotify = new UtilNotify.NotifyManager();
         CtrlNotify.createAlert(
-            _('Select an area for recording or press [ESC] to abort'));
+            _("Select an area for recording or press [ESC] to abort")
+        );
     },
 
     /**
@@ -239,33 +241,43 @@ const SelectionArea = new Lang.Class({
             } else if (type === Clutter.EventType.BUTTON_RELEASE) {
                 this._capture._stop();
 
-                Lib.TalkativeLog('-£-area x: ' + rect.x + ' y: ' + rect.y + ' height: ' + rect.h + 'width: ' + rect.w);
+                Lib.TalkativeLog(
+                    "-£-area x: " +
+                        rect.x +
+                        " y: " +
+                        rect.y +
+                        " height: " +
+                        rect.h +
+                        "width: " +
+                        rect.w
+                );
 
                 this._capture._saveRect(rect.x, rect.y, rect.h, rect.w);
             }
         }
-    }
+    },
 });
 
 Signals.addSignalMethods(SelectionArea.prototype);
 
-const SelectionWindow = new Lang.Class({
+var SelectionWindow = new Lang.Class({
     Name: "EasyScreenCast.SelectionWindow",
 
     /**
      * @private
      */
     _init: function () {
-        Lib.TalkativeLog('-£-window selection init');
+        Lib.TalkativeLog("-£-window selection init");
 
         this._windows = global.get_window_actors();
         this._capture = new Capture();
-        this._capture.connect('captured-event', this._onEvent.bind(this));
-        this._capture.connect('stop', this.emit.bind(this, 'stop'));
+        this._capture.connect("captured-event", this._onEvent.bind(this));
+        this._capture.connect("stop", this.emit.bind(this, "stop"));
 
         let CtrlNotify = new UtilNotify.NotifyManager();
         CtrlNotify.createAlert(
-            _('Select a window for recording or press [ESC] to abort'));
+            _("Select a window for recording or press [ESC] to abort")
+        );
     },
 
     /**
@@ -291,12 +303,26 @@ const SelectionWindow = new Lang.Class({
 
                 var max_height = global.screen_height;
                 var max_width = global.screen_width;
-                Lib.TalkativeLog('-£-global screen area H: ' + max_height + ' W: ' + max_width);
+                Lib.TalkativeLog(
+                    "-£-global screen area H: " +
+                        max_height +
+                        " W: " +
+                        max_width
+                );
 
                 var [w, h] = this._selectedWindow.get_size();
                 var [wx, wy] = this._selectedWindow.get_position();
 
-                Lib.TalkativeLog('-£-windows pre wx: ' + wx + ' wy: ' + wy + ' height: ' + h + '  width: ' + w);
+                Lib.TalkativeLog(
+                    "-£-windows pre wx: " +
+                        wx +
+                        " wy: " +
+                        wy +
+                        " height: " +
+                        h +
+                        "  width: " +
+                        w
+                );
 
                 if (wx < 0) {
                     wx = 0;
@@ -314,7 +340,16 @@ const SelectionWindow = new Lang.Class({
                     h = max_height - wy;
                 }
 
-                Lib.TalkativeLog('-£-windows post wx: ' + wx + ' wy: ' + wy + ' height: ' + h + ' width: ' + w);
+                Lib.TalkativeLog(
+                    "-£-windows post wx: " +
+                        wx +
+                        " wy: " +
+                        wy +
+                        " height: " +
+                        h +
+                        " width: " +
+                        w
+                );
 
                 this._capture._saveRect(wx, wy, h, w);
             }
@@ -327,7 +362,16 @@ const SelectionWindow = new Lang.Class({
      */
     _highlightWindow: function (win) {
         let rect = getWindowRectangle(win);
-        Lib.TalkativeLog('-£-window highlight on, pos/meas: x:' + rect.x + ' y:' + rect.y + ' w:' + rect.w + ' h:' + rect.h);
+        Lib.TalkativeLog(
+            "-£-window highlight on, pos/meas: x:" +
+                rect.x +
+                " y:" +
+                rect.y +
+                " w:" +
+                rect.w +
+                " h:" +
+                rect.h
+        );
         this._capture.drawSelection(rect, false);
     },
 
@@ -335,9 +379,9 @@ const SelectionWindow = new Lang.Class({
      * @private
      */
     _clearHighlight: function () {
-        Lib.TalkativeLog('-£-window highlight off');
+        Lib.TalkativeLog("-£-window highlight off");
         this._capture.clearSelection();
-    }
+    },
 });
 
 Signals.addSignalMethods(SelectionWindow.prototype);
@@ -349,25 +393,35 @@ var SelectionDesktop = new Lang.Class({
      * @private
      */
     _init: function () {
-        Lib.TalkativeLog('-£-desktop selection init');
+        Lib.TalkativeLog("-£-desktop selection init");
         const number_displays = display_api.number_displays();
-        Lib.TalkativeLog('-£-Number of monitor ' + number_displays);
+        Lib.TalkativeLog("-£-Number of monitor " + number_displays);
 
         for (var i = 0; i < number_displays; i++) {
             var tmpM = new Layout.Monitor(
                 i,
                 display_api.display_geometry_for_index(i)
             );
-            Lib.TalkativeLog('-£-monitor geometry x=' + tmpM.x + ' y=' + tmpM.y + ' w=' + tmpM.width + ' h=' + tmpM.height);
+            Lib.TalkativeLog(
+                "-£-monitor geometry x=" +
+                    tmpM.x +
+                    " y=" +
+                    tmpM.y +
+                    " w=" +
+                    tmpM.width +
+                    " h=" +
+                    tmpM.height
+            );
         }
 
         this._capture = new Capture();
-        this._capture.connect('captured-event', this._onEvent.bind(this));
-        this._capture.connect('stop', this.emit.bind(this, 'stop'));
+        this._capture.connect("captured-event", this._onEvent.bind(this));
+        this._capture.connect("stop", this.emit.bind(this, "stop"));
 
         let CtrlNotify = new UtilNotify.NotifyManager();
         CtrlNotify.createAlert(
-            _('Select a desktop for recording or press [ESC] to abort'));
+            _("Select a desktop for recording or press [ESC] to abort")
+        );
     },
 
     /**
@@ -387,11 +441,20 @@ var SelectionDesktop = new Lang.Class({
             var y = tmpM.y;
             var height = tmpM.height;
             var width = tmpM.width;
-            Lib.TalkativeLog('-£-desktop x: ' + x + ' y: ' + y + ' height: ' + height + 'width: ' + width);
+            Lib.TalkativeLog(
+                "-£-desktop x: " +
+                    x +
+                    " y: " +
+                    y +
+                    " height: " +
+                    height +
+                    "width: " +
+                    width
+            );
 
             this._capture._saveRect(x, y, height, width);
         }
-    }
+    },
 });
 
 Signals.addSignalMethods(SelectionDesktop.prototype);
@@ -403,42 +466,40 @@ const AreaRecording = new Lang.Class({
      * @private
      */
     _init: function () {
-        Lib.TalkativeLog('-£-area recording init');
+        Lib.TalkativeLog("-£-area recording init");
 
         this._areaRecording = new St.Widget({
-            name: 'area-recording',
-            style_class: 'area-recording',
-            visible: 'true',
-            reactive: 'false',
+            name: "area-recording",
+            style_class: "area-recording",
+            visible: "true",
+            reactive: "false",
             x: -10,
-            y: -10
+            y: -10,
         });
 
-        var recX = Settings.getOption('i', Settings.X_POS_SETTING_KEY);
-        var recY = Settings.getOption('i', Settings.Y_POS_SETTING_KEY);
-        var recW = Settings.getOption('i', Settings.WIDTH_SETTING_KEY);
-        var recH = Settings.getOption('i', Settings.HEIGHT_SETTING_KEY);
+        var recX = Settings.getOption("i", Settings.X_POS_SETTING_KEY);
+        var recY = Settings.getOption("i", Settings.Y_POS_SETTING_KEY);
+        var recW = Settings.getOption("i", Settings.WIDTH_SETTING_KEY);
+        var recH = Settings.getOption("i", Settings.HEIGHT_SETTING_KEY);
 
         var tmpH = Main.layoutManager.currentMonitor.height;
         var tmpW = Main.layoutManager.currentMonitor.width;
 
         Main.uiGroup.add_actor(this._areaRecording);
 
-        Main.overview.connect('showing',
-            () => {
-                Lib.TalkativeLog('-£-overview opening');
+        Main.overview.connect("showing", () => {
+            Lib.TalkativeLog("-£-overview opening");
 
-                Main.uiGroup.remove_actor(this._areaRecording);
-            });
+            Main.uiGroup.remove_actor(this._areaRecording);
+        });
 
-        Main.overview.connect('hidden',
-            () => {
-                Lib.TalkativeLog('-£-overview closed');
+        Main.overview.connect("hidden", () => {
+            Lib.TalkativeLog("-£-overview closed");
 
-                Main.uiGroup.add_actor(this._areaRecording);
-            });
+            Main.uiGroup.add_actor(this._areaRecording);
+        });
 
-        if ((recX + recW <= tmpW - 5) && (recY + recH <= tmpH - 5)) {
+        if (recX + recW <= tmpW - 5 && recY + recH <= tmpH - 5) {
             this.drawArea(recX - 2, recY - 2, recW + 4, recH + 4);
         }
     },
@@ -450,7 +511,7 @@ const AreaRecording = new Lang.Class({
      * @param {Number} h
      */
     drawArea: function (x, y, w, h) {
-        Lib.TalkativeLog('-£-draw area recording');
+        Lib.TalkativeLog("-£-draw area recording");
 
         this._visible = true;
         this._areaRecording.set_position(x, y);
@@ -461,7 +522,7 @@ const AreaRecording = new Lang.Class({
      * Clears the drawing area
      */
     clearArea: function () {
-        Lib.TalkativeLog('-£-hide area recording');
+        Lib.TalkativeLog("-£-hide area recording");
 
         this._visible = false;
         this.drawArea(-10, -10, 0, 0);
@@ -472,7 +533,7 @@ const AreaRecording = new Lang.Class({
      */
     isVisible: function () {
         return this._visible;
-    }
+    },
 });
 
 Signals.addSignalMethods(AreaRecording.prototype);
@@ -489,7 +550,7 @@ const getRectangle = function (x1, y1, x2, y2) {
         x: Math.min(x1, x2),
         y: Math.min(y1, y2),
         w: Math.abs(x1 - x2),
-        h: Math.abs(y1 - y2)
+        h: Math.abs(y1 - y2),
     };
 };
 
@@ -505,7 +566,7 @@ const getWindowRectangle = function (win) {
         x: tx,
         y: ty,
         w: tw,
-        h: th
+        h: th,
     };
 };
 
@@ -517,24 +578,29 @@ const getWindowRectangle = function (win) {
  */
 const selectWindow = function (windows, x, y) {
     let filtered = windows.filter(function (win) {
-        if ((win !== undefined) && win.visible &&
-            (typeof win.get_meta_window === 'function')) {
-            Lib.TalkativeLog('-£-selectWin x:' + x + ' y:' + y);
+        if (
+            win !== undefined &&
+            win.visible &&
+            typeof win.get_meta_window === "function"
+        ) {
+            Lib.TalkativeLog("-£-selectWin x:" + x + " y:" + y);
 
             let [w, h] = win.get_size();
             let [wx, wy] = win.get_position();
-            Lib.TalkativeLog('-£-selectWin w:' + w + ' h:' + h + 'wx:' + wx + ' wy:' + wy);
-
-            return (
-                (wx <= x) && (wy <= y) && ((wx + w) >= x) && ((wy + h) >= y)
+            Lib.TalkativeLog(
+                "-£-selectWin w:" + w + " h:" + h + "wx:" + wx + " wy:" + wy
             );
+
+            return wx <= x && wy <= y && wx + w >= x && wy + h >= y;
         } else {
             return false;
         }
     });
 
     filtered.sort(function (a, b) {
-        return a.get_meta_window().get_layer() <= b.get_meta_window().get_layer();
+        return (
+            a.get_meta_window().get_layer() <= b.get_meta_window().get_layer()
+        );
     });
 
     return filtered[0];
