@@ -12,11 +12,12 @@
 
 const Lang = imports.lang;
 const GLib = imports.gi.GLib;
-imports.gi.versions.Gst = '1.0';
+imports.gi.versions.Gst = "1.0";
 const Gst = imports.gi.Gst;
 
 const Gettext = imports.gettext.domain(
-    'EasyScreenCast@iacopodeenosee.gmail.com');
+    "EasyScreenCast@iacopodeenosee.gmail.com"
+);
 const _ = Gettext.gettext;
 
 const ExtensionUtils = imports.misc.extensionUtils;
@@ -33,17 +34,19 @@ var HelperWebcam = new Lang.Class({
      * Create a device monitor inputvideo
      */
     _init: function () {
-        Lib.TalkativeLog('-@-init webcam');
+        Lib.TalkativeLog("-@-init webcam");
 
         Gst.init(null);
 
         //get gstreamer lib version
         var [M, m, micro, nano] = Gst.version();
-        Lib.TalkativeLog('-@-gstreamer version: ' + M + '.' + m + '.' + micro + '.' + nano);
+        Lib.TalkativeLog(
+            "-@-gstreamer version: " + M + "." + m + "." + micro + "." + nano
+        );
         if (M === 1 && m >= 8) {
             //gstreamer version equal or higher 1.8
             this.deviceMonitor = new Gst.DeviceMonitor({
-                show_all: true
+                show_all: true,
             });
         } else {
             //gstreamer version lower 1.8
@@ -53,28 +56,39 @@ var HelperWebcam = new Lang.Class({
         //get gstreamer plugin avaiable
         let registry = new Gst.Registry();
         let listPI = registry.get_plugin_list();
-        Lib.TalkativeLog('-@-plugin list: ' + listPI.length);
+        Lib.TalkativeLog("-@-plugin list: " + listPI.length);
         for (var ind in listPI) {
-            Lib.TalkativeLog('-@-plugin name: ' + listPI[ind].get_name() + ' Pfilename: ' + listPI[ind].get_filename() + ' Pdesc:  ' + listPI[ind].get_description() + ' Pversion: ' + listPI[ind].get_version() + ' Pload: ' + listPI[ind].is_loaded());
+            Lib.TalkativeLog(
+                "-@-plugin name: " +
+                    listPI[ind].get_name() +
+                    " Pfilename: " +
+                    listPI[ind].get_filename() +
+                    " Pdesc:  " +
+                    listPI[ind].get_description() +
+                    " Pversion: " +
+                    listPI[ind].get_version() +
+                    " Pload: " +
+                    listPI[ind].is_loaded()
+            );
         }
 
         //create device monitor
         if (this.deviceMonitor !== null && this.deviceMonitor !== undefined) {
-            Lib.TalkativeLog('-@-device monitor created');
+            Lib.TalkativeLog("-@-device monitor created");
             this.dmBus = this.deviceMonitor.get_bus();
             if (this.dmBus !== null && this.dmBus !== undefined) {
-                Lib.TalkativeLog('-@-dbus created');
-                this.dmBus.add_watch(GLib.PRIORITY_DEFAULT, this._getMsg);
-                let caps = Gst.Caps.new_empty_simple('video/x-raw');
-                this.deviceMonitor.add_filter('Video/Source', caps);
+                Lib.TalkativeLog("-@-dbus created");
+                this.dmBus.add_watch(GLib.PRIORITY_DEFAULT, this._getMsg.bind(this));
+                let caps = Gst.Caps.new_empty_simple("video/x-raw");
+                this.deviceMonitor.add_filter("Video/Source", caps);
                 this.startMonitor();
                 //update device and caps
                 this.refreshAllInputVideo();
             } else {
-                Lib.TalkativeLog('-@-ERROR dbus creation');
+                Lib.TalkativeLog("-@-ERROR dbus creation");
             }
         } else {
-            Lib.TalkativeLog('-@-ERROR device monitor creation');
+            Lib.TalkativeLog("-@-ERROR device monitor creation");
         }
     },
 
@@ -84,22 +98,22 @@ var HelperWebcam = new Lang.Class({
      * @return {string}
      */
     _getMsg: function (bus, message) {
-        Lib.TalkativeLog('-@-event getmsg');
+        Lib.TalkativeLog("-@-event getmsg");
         switch (message.type) {
             case Gst.MessageType.DEVICE_ADDED:
-                Lib.TalkativeLog('Device added');
+                Lib.TalkativeLog("Device added");
 
                 //update device and caps
                 this.refreshAllInputVideo();
                 break;
             case Gst.MessageType.DEVICE_REMOVED:
-                Lib.TalkativeLog('Device removed');
+                Lib.TalkativeLog("Device removed");
 
                 //update device and caps
                 this.refreshAllInputVideo();
                 break;
             default:
-                Lib.TalkativeLog('Device UNK');
+                Lib.TalkativeLog("Device UNK");
                 break;
         }
 
@@ -110,18 +124,24 @@ var HelperWebcam = new Lang.Class({
      * refresh all devices info
      */
     refreshAllInputVideo: function () {
-        Lib.TalkativeLog('-@-refresh all video input');
+        Lib.TalkativeLog("-@-refresh all video input");
 
         ListDevices = this.getDevicesIV();
         //compose devices array
         ListCaps = [];
         for (var index in ListDevices) {
-            ListCaps[index] =
-                this.getCapsForIV(ListDevices[index].caps);
+            ListCaps[index] = this.getCapsForIV(ListDevices[index].caps);
 
-            Lib.TalkativeLog('-@-webcam /dev/video' + index + ' name: ' + ListDevices[index].display_name);
-            Lib.TalkativeLog('-@-caps avaiable N°: ' + ListCaps[index].length);
-            Lib.TalkativeLog('-@-ListCaps[' + index + ']' + ': ' + ListCaps[index]);
+            Lib.TalkativeLog(
+                "-@-webcam /dev/video" +
+                    index +
+                    " name: " +
+                    ListDevices[index].display_name
+            );
+            Lib.TalkativeLog("-@-caps avaiable N°: " + ListCaps[index].length);
+            Lib.TalkativeLog(
+                "-@-ListCaps[" + index + "]" + ": " + ListCaps[index]
+            );
         }
     },
 
@@ -129,19 +149,21 @@ var HelperWebcam = new Lang.Class({
      * get caps from device
      */
     getCapsForIV: function (tmpCaps) {
-        Lib.TalkativeLog('-@-get all caps from a input video');
-        Lib.TalkativeLog('-@-caps avaiable N°: ' + tmpCaps.get_size());
+        Lib.TalkativeLog("-@-get all caps from a input video");
+        Lib.TalkativeLog("-@-caps avaiable N°: " + tmpCaps.get_size());
 
         var cleanCaps = [];
         for (var i = 0; i < tmpCaps.get_size(); i++) {
             //cleaned cap
-            var tmpStr = tmpCaps.get_structure(i).to_string()
-                .replace(/;/gi, '');
+            var tmpStr = tmpCaps
+                .get_structure(i)
+                .to_string()
+                .replace(/;/gi, "");
 
             //fine cleaning of option CAPS remain
             cleanCaps[i] = this.cleanCapsOPT(tmpStr);
 
-            Lib.TalkativeLog('-@-cap : ' + i + ' : ' + cleanCaps[i]);
+            Lib.TalkativeLog("-@-cap : " + i + " : " + cleanCaps[i]);
         }
         return cleanCaps;
     },
@@ -153,24 +175,23 @@ var HelperWebcam = new Lang.Class({
      * @return {array}
      */
     cleanCapsOPT: function (strCaps) {
-        Lib.TalkativeLog('-@-fine tunning caps:' + strCaps);
+        Lib.TalkativeLog("-@-fine tunning caps:" + strCaps);
 
-        if (strCaps.indexOf('{ ') >= 0) {
+        if (strCaps.indexOf("{ ") >= 0) {
             //clean
-            var firstOPT = strCaps.indexOf('{ ');
-            var lastOPT = strCaps.indexOf(' }');
-            var nextMedia = strCaps.indexOf(',', firstOPT);
-            if (strCaps.indexOf(',', firstOPT) + 1 > lastOPT + 2) {
+            var firstOPT = strCaps.indexOf("{ ");
+            var lastOPT = strCaps.indexOf(" }");
+            var nextMedia = strCaps.indexOf(",", firstOPT);
+            if (strCaps.indexOf(",", firstOPT) + 1 > lastOPT + 2) {
                 nextMedia = lastOPT;
             }
 
             var strInitial = strCaps.substr(0, firstOPT);
-            var strMedia = strCaps.substring(firstOPT + 2,
-                nextMedia);
+            var strMedia = strCaps.substring(firstOPT + 2, nextMedia);
             var strPost = strCaps.substr(lastOPT + 2);
 
             var tmpStr = strInitial + strMedia + strPost;
-            Lib.TalkativeLog('-@-cleaned caps:' + tmpStr);
+            Lib.TalkativeLog("-@-cleaned caps:" + tmpStr);
             //recall
             return this.cleanCapsOPT(tmpStr);
         } else {
@@ -184,10 +205,10 @@ var HelperWebcam = new Lang.Class({
      * @return {array}
      */
     getDevicesIV: function () {
-        Lib.TalkativeLog('-@-get devices');
+        Lib.TalkativeLog("-@-get devices");
 
         var list = this.deviceMonitor.get_devices();
-        Lib.TalkativeLog('-@-devices number: ' + list.length);
+        Lib.TalkativeLog("-@-devices number: " + list.length);
 
         return list;
     },
@@ -198,20 +219,20 @@ var HelperWebcam = new Lang.Class({
      * @return {array}
      */
     getNameDevices: function () {
-        Lib.TalkativeLog('-@-get name devices');
+        Lib.TalkativeLog("-@-get name devices");
         let tmpArray = [];
 
         for (var index in ListDevices) {
-            var wcName = _('Unspecified webcam');
+            var wcName = _("Unspecified webcam");
 
-            if (ListDevices[index].display_name !== '') {
-                wcName = ListDevices[index].display_name
+            if (ListDevices[index].display_name !== "") {
+                wcName = ListDevices[index].display_name;
             }
 
             tmpArray.push(wcName);
         }
 
-        Lib.TalkativeLog('-@-list devices name: ' + tmpArray);
+        Lib.TalkativeLog("-@-list devices name: " + tmpArray);
         return tmpArray;
     },
 
@@ -223,7 +244,7 @@ var HelperWebcam = new Lang.Class({
      */
     getListCapsDevice: function (device) {
         const tmpArray = ListCaps[device];
-        Lib.TalkativeLog('-@-list caps of device: ' + tmpArray);
+        Lib.TalkativeLog("-@-list caps of device: " + tmpArray);
 
         return tmpArray;
     },
@@ -232,7 +253,7 @@ var HelperWebcam = new Lang.Class({
      * start listening
      */
     startMonitor: function () {
-        Lib.TalkativeLog('-@-start video devicemonitor');
+        Lib.TalkativeLog("-@-start video devicemonitor");
         this.deviceMonitor.start();
     },
 
@@ -240,7 +261,7 @@ var HelperWebcam = new Lang.Class({
      * Stop listening
      */
     stopMonitor: function () {
-        Lib.TalkativeLog('-@-stop video devicemonitor');
+        Lib.TalkativeLog("-@-stop video devicemonitor");
         this.disconnectSourceBus();
         this.deviceMonitor.stop();
     },
@@ -253,5 +274,5 @@ var HelperWebcam = new Lang.Class({
             this.dmBus.disconnect(this.dmBusId);
             this.dmBusId = 0;
         }
-    }
+    },
 });
